@@ -1,9 +1,6 @@
 __title__ = "Mock CLI Framework"
-__version__ = "0.1.1"
-__summary__ = """A framework for creating stand-ins for CLI tools that pretend
-to be the real thing for when "the real thing" isn't suitable, such as in
-automated tests.
-"""
+__version__ = "0.1.2"
+__summary__ = """A framework for creating stand-ins for CLI tools that pretend to be the real thing for when "the real thing" isn't suitable, such as in automated tests."""
 
 """
 See PEP 440 for version scheme
