@@ -4,8 +4,8 @@ from .responses import ResponseDirectory
 
 
 class MockCommand:
-    def __init__(self, response_directory_path):
-        self.response_directory = ResponseDirectory(response_directory_path)
+    def __init__(self, responsedir_json_file):
+        self.response_directory = ResponseDirectory(responsedir_json_file)
 
     def _write_binary(self, output_handle, data):
         with os.fdopen(output_handle.fileno(), "wb", closefd=False) as fd:
